@@ -1,5 +1,5 @@
 from .make import make_project  # noqa
 from .remove_poetry import remove_poetry  # noqa
-from .setup_pg import setup_postgres  # noqa
+from .rm_migrations import rm_migrations  # noqa
 from .work import work  # noqa
 from .write_env import write_env_file  # noqa
